# VFMC

VFMC is a tool for practicing FMC attempts virtually.

See video explanation [here](https://www.youtube.com/playlist?list=PLgG41rIZp6JsT2FIP074K6w9nOfUSL3dv)

# Installation

Windows and Mac executables can be found [here](https://github.com/rodneykinney/VFMC/releases/latest)

On any platform, you can also install and run from the command line:
```
# Requires Python version 3.9 or later:
python --version

# Install with pip
python -m pip install vfmc

# Run
vfmc
```

# Approach

VFMC tracks all the steps of an FMC attempt: EO - DR - HTR - (FR) - Slice - Finish. 

## A realistic alternative to pencil+paper+cube

Find similar solutions to what you would find in a manual attempt.
You should be able to do it more quickly than in a manual attempt, because you can cut out time 
normally spent scrambling, NISS-ing, and recovering from mistakes.

## Depth-vs-breadth trade-offs

Decide how many solutions to write down for each step, 
and how much time to spend on each of them. Decide what works best for you.

## Case recognition

See, at each step, the case name for getting to the next step, and show the bad pieces 
that must be solved to get there.

## Optimal solutions for each step

Use the integrated solver to find the shortest solution for reaching the next step that 
hasn't been written down already.

<img width="1312" alt="image" src="https://github.com/user-attachments/assets/bd1ba408-0f60-4090-a116-59d5496add15" />

